@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import Callable
+from typing import Callable, Any
 from pywirelessmbus.utils import WMbusMessage
 from pywirelessmbus.utils.utils import NOOP
 
@@ -7,10 +7,13 @@ from pywirelessmbus.utils.utils import NOOP
 class Device(ABC):
     on_set_aes_key: Callable[[int, str, bytes], None]
 
-    def __init__(self, device_id: str, index: int, on_set_aes_key=NOOP):
+    def __init__(
+        self, device_id: str, index: int, label: str = "", on_set_aes_key=NOOP
+    ):
         self.id = device_id
         self.index = index
         self.on_set_aes_key = on_set_aes_key
+        self.label = label
 
     @abstractmethod
     def process_new_message(self, message: WMbusMessage) -> WMbusMessage:
